.. image:: https://coveralls.io/repos/github/xlcnd/isbnlib-loc/badge.svg?branch=dev
    :target: https://coveralls.io/github/xlcnd/isbnlib-loc?branch=dev
    :alt: Coverage Status

.. image:: https://travis-ci.org/xlcnd/isbnlib-loc.svg?branch=dev
    :target: https://travis-ci.org/xlcnd/isbnlib-loc
    :alt: Built Status

.. image:: https://ci.appveyor.com/api/projects/status/github/xlcnd/isbnlib-loc?branch=dev&svg=true
    :target: https://ci.appveyor.com/project/xlcnd/isbnlib-loc
    :alt: Windows Built Status

.. image:: https://img.shields.io/github/issues/xlcnd/isbnlib-loc/bug.svg?label=bugs&style=flat
    :target: https://github.com/xlcnd/isbnlib-loc/labels/bug
    :alt: Bugs

.. image:: https://img.shields.io/pypi/dm/isbnlib-loc.svg?style=flat
    :target: https://pypi.org/project/isbnlib-loc/
    :alt: PYPI Downloads



A metadata plugin for ``isbnlib`` (https://pypi.python.org/pypi/isbnlib) using the service LoC (Library of Congress US).

After install, a new metadata provider (``loc``) is available in isbnlib.

For available plugins check_ here.



.. _check: https://pypi.python.org/pypi?%3Aaction=search&term=isbnlib_&submit=search

